@@ -1,7 +1,7 @@
 """
 Componente de uso de diversas funcionalidades do python.
 Como por exemplo: instalar pacotes, gerar e instalar
-arquivo requiriments.txt e i
+arquivo requiriments.txt
 """
 
 import subprocess
